@@ -1,6 +1,7 @@
 from .argo_client import ArgoClient
 from .argo_options import ArgoOptions
-from .dsl import DAG, CronWorkflow, Task, Workflow, WorkflowTemplate
+from .dsl import CronWorkflow, Workflow, WorkflowTemplate
+import argo_workflow_tools.dsl.dsl_decorators as dsl
 from .dsl.condition import Condition
 from .exceptions.workflow_not_found_exception import WorkflowNotFoundException
 from .workflow_result import WorkflowResult
