@@ -7,6 +7,7 @@ from argo_workflow_tools.dsl.utils.path_builder import (
     parameter_path,
     with_item_path,
 )
+from argo_workflow_tools.dsl.utils.utils import convert_str
 
 
 class SourceType(Enum):
@@ -30,7 +31,8 @@ class InputDefinition:
         references: Optional["InputDefinition"] = None,
         parameter_builder: ParameterBuilder = None,
         key_name: str = None,
-        value: str = None
+        value: str = None,
+        default: any = None,
     ):
         self.source_type = source_type
         self.name = name
@@ -38,7 +40,8 @@ class InputDefinition:
         self.reference = references
         self.parameter_builder = parameter_builder
         self.key_name = key_name
-        self.value = value
+        self.value = convert_str(value)
+        self.default = convert_str(default)
 
     @property
     def is_node_output(self):
@@ -83,7 +86,7 @@ class InputDefinition:
             if self.is_node_output:
                 return task_output_path(self.source_node_id, self.name, self.key_name)
             else:
-                if self.source_type==SourceType.PARAMETER:
+                if self.source_type == SourceType.PARAMETER:
                     return parameter_path(self.name, self.key_path)
                 else:
                     return self.value
